KnowledgeBaseQuery

Struct KnowledgeBaseQuery 

pub struct KnowledgeBaseQuery {
    pub params: Vec<(&'static str, String)>,
}

Fields

params: Vec<(&'static str, String)>

Implementations

Source

impl KnowledgeBaseQuery

pub fn with_cursor(self, cursor: impl Into<String>) -> KnowledgeBaseQuery

Used for fetching next page. Cursor is returned in the response.

pub fn with_page_size(self, page_size: u32) -> KnowledgeBaseQuery

How many documents to return at maximum. Can not exceed 100, defaults to 30.

If specified, the endpoint returns only such knowledge base documents whose names start with this string.

pub fn show_only_owned_documents(self) -> KnowledgeBaseQuery

If set to true, the endpoint will return only documents owned by you (and not shared from somebody else). Defaults to false.

pub fn use_typesense(self) -> KnowledgeBaseQuery

If set to true, the endpoint will use typesense DB to search for the documents. Defaults to false.